==> freeplane_1.5.18.orig.tar.gz: freeplane-1.5.18/freeplane_framework/test_data/StructuredMapTest.mm <==
<map version="freeplane 1.3.0">
<!--To view this file, download free mind mapping software Freeplane from http://freeplane.sourceforge.net -->
<node TEXT="Title of the Map" LOCALIZED_STYLE_REF="AutomaticLayout.level.root" FOLDED="false" ID="ID_1723255651" CREATED="1283093380553" MODIFIED="1369771838184"><hook NAME="MapStyle" zoom="0.75">

<map_styles>
<stylenode LOCALIZED_TEXT="styles.root_node">
<stylenode LOCALIZED_TEXT="styles.predefined" POSITION="right">
<stylenode LOCALIZED_TEXT="default" MAX_WIDTH="600" COLOR="#000000" STYLE="as_parent">
<font NAME="SansSerif" SIZE="10" BOLD="false" ITALIC="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.details" COLOR="#5a4de4"/>
<stylenode LOCALIZED_TEXT="defaultstyle.note" COLOR="#991414"/>
<stylenode LOCALIZED_TEXT="defaultstyle.floating">
<edge STYLE="hide_edge"/>
<cloud COLOR="#f0f0f0" SHAPE="ROUND_RECT"/>
</stylenode>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.user-defined" POSITION="right">
<stylenode LOCALIZED_TEXT="styles.topic" COLOR="#18898b" STYLE="fork">
<font NAME="Liberation Sans" SIZE="10" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subtopic" COLOR="#cc3300" STYLE="fork">
<font NAME="Liberation Sans" SIZE="10" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subsubtopic" COLOR="#669900">
<font NAME="Liberation Sans" SIZE="10" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.important">
<icon BUILTIN="yes"/>
</stylenode>
<stylenode TEXT="My Custom Style" COLOR="#1a9914" BACKGROUND_COLOR="#9fa9ef">
<font SIZE="22" BOLD="true"/>
<edge COLOR="#00ff00"/>
</stylenode>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.AutomaticLayout" POSITION="right">
<stylenode LOCALIZED_TEXT="AutomaticLayout.level.root" COLOR="#000000">
<font SIZE="18"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,1" COLOR="#0033ff">
<font SIZE="16"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,2" COLOR="#00b439">
<font SIZE="14"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,3" COLOR="#990000">
<font SIZE="12"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,4" COLOR="#111111">
<font SIZE="10"/>
</stylenode>
</stylenode>
</stylenode>
</map_styles>
</hook>
<hook NAME="AutomaticEdgeColor" COUNTER="5"/>
<node TEXT="Intro" LOCALIZED_STYLE_REF="AutomaticLayout.level,1" POSITION="right" ID="ID_708159329" CREATED="1360711330056" MODIFIED="1360937837727">
<edge COLOR="#ff0000"/>
<node TEXT="This should be &quot;Body text&quot;. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua." ID="ID_1000279327" CREATED="1360711330056" MODIFIED="1360937489828"/>
</node>
<node TEXT="A Section" LOCALIZED_STYLE_REF="AutomaticLayout.level,1" POSITION="right" ID="ID_1009103810" CREATED="1360711330082" MODIFIED="1360937837734">
<edge COLOR="#00ff00"/>
<node TEXT="This should be &quot;Body text&quot;. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua." ID="ID_185418190" CREATED="1360711330056" MODIFIED="1360937489828"/>
<node TEXT="Expected Behaviour" LOCALIZED_STYLE_REF="AutomaticLayout.level,2" ID="ID_1935555534" CREATED="1360711330141" MODIFIED="1360937832275">
<node TEXT="This should be &quot;Body text&quot;. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua." ID="ID_172406032" CREATED="1360711330056" MODIFIED="1360937489828"/>
<node TEXT="This text has Freeplane predefined style &quot;Details&quot; and should ideally become custom ODT-style &quot;details&quot;, too. detail, detail, detail, detail, detail, detail, detail, detail, detail, detail." LOCALIZED_STYLE_REF="defaultstyle.details" ID="ID_1286931197" CREATED="1360711330227" MODIFIED="1369934481347"/>
<node TEXT="This text has Freeplane predefined style &quot;Note&quot; and should ideally become custom ODT-style &quot;note&quot;, too. note, note, note, note, note, note, note, note." LOCALIZED_STYLE_REF="defaultstyle.note" ID="ID_409213814" CREATED="1360711330227" MODIFIED="1369767861422"/>
<node TEXT="The same should be true for other custom freeplane styles." ID="ID_939096506" CREATED="1360938425065" MODIFIED="1369767836466"/>
</node>
<node TEXT="Further improvement" LOCALIZED_STYLE_REF="AutomaticLayout.level,2" ID="ID_831477544" CREATED="1360711330213" MODIFIED="1360937855895">
<node TEXT="Now here are some ideas for further improvement:" ID="ID_1274680809" CREATED="1360711330056" MODIFIED="1360937943450"/>
<node TEXT="Nodes with &quot;node-numbering&quot; turned on should become numbered lists." ID="ID_1047522289" CREATED="1360938043210" MODIFIED="1369775173285">
<node TEXT="one" ID="ID_224533182" CREATED="1360937991333" MODIFIED="1360937994822" NUMBERED="true"/>
<node TEXT="two" ID="ID_1539142837" CREATED="1360937995693" MODIFIED="1360937999407" NUMBERED="true">
<node TEXT="one" LOCALIZED_STYLE_REF="default" ID="ID_460784059" CREATED="1360937991333" MODIFIED="1369934338039" NUMBERED="true"/>
<node TEXT="two" LOCALIZED_STYLE_REF="default" ID="ID_1390007073" CREATED="1360937995693" MODIFIED="1369934338056" NUMBERED="true"/>
<node TEXT="three" LOCALIZED_STYLE_REF="default" ID="ID_174188200" CREATED="1360938000382" MODIFIED="1369934338063" NUMBERED="true"/>
</node>
<node TEXT="three" ID="ID_1491209579" CREATED="1360938000382" MODIFIED="1360938002357" NUMBERED="true"/>
</node>
</node>
<node TEXT="Notes and rich-text nodes" LOCALIZED_STYLE_REF="AutomaticLayout.level,2" ID="ID_572664818" CREATED="1360938477054" MODIFIED="1360938526821">
<node ID="ID_850381882" CREATED="1360938533372" MODIFIED="1369945500063"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      Rich-texts nodes should just become formated as the rich-text is, using ODT-style &quot;body text&quot;.
    </p>
    <ul>
      <li>
        This is a first unnumbered list item in a rich-tex-node
      </li>
      <li>
        This is a second unnumbered list item in a rich-tex-no
      </li>
      <li>
        This is a forth unnumbered list item in a rich-tex-node
      </li>
    </ul>
  </body>
</html>

</richcontent>
</node>
<node TEXT="Rich-text Nodes and details should be formated the same." ID="ID_102700945" CREATED="1360938606807" MODIFIED="1369934446482"/>
</node>
</node>
<node TEXT="This Section has not styles applied" LOCALIZED_STYLE_REF="default" FOLDED="true" POSITION="right" ID="ID_52684190" CREATED="1360711330232" MODIFIED="1369771408084">
<edge COLOR="#007c7c"/>
<node TEXT="Thies section does not have any styles set. So this all sould becom text body, except if automatic stlyes are on." ID="ID_885260680" CREATED="1369771340439" MODIFIED="1369775408113" BACKGROUND_COLOR="#ffffff"/>
<node TEXT="Subsection (Level 2)" ID="ID_1705364067" CREATED="1360937370766" MODIFIED="1369770969648">
<node TEXT="Subsubsection (Level 3)" ID="ID_1625498929" CREATED="1360937370766" MODIFIED="1369770986673">
<node TEXT="Level 4 without a sub-node" ID="ID_1344868067" CREATED="1369770993387" MODIFIED="1369771189078"/>
</node>
</node>
<node TEXT="Subsection (Level 2)" ID="ID_626605938" CREATED="1360937370766" MODIFIED="1369770979798">
<node TEXT="Subsubsection (Level 3)" ID="ID_1557349195" CREATED="1360937370766" MODIFIED="1369770986673">
<node TEXT="Level 4 with a node below" ID="ID_539388565" CREATED="1369770993387" MODIFIED="1369771087624">
<node TEXT="Level 5" ID="ID_1912854001" CREATED="1369770996803" MODIFIED="1369771000193"/>
</node>
</node>
</node>
<node TEXT="Level 2 without sub.node" ID="ID_89526220" CREATED="1360937370766" MODIFIED="1369771069832"/>
<node TEXT="Subsection (Level 2)" ID="ID_1116673985" CREATED="1360937370766" MODIFIED="1369770979798">
<node TEXT="Level 3 without sub-node" ID="ID_1980164007" CREATED="1360937370766" MODIFIED="1369771137633"/>
</node>
</node>
<node TEXT="But this section has styles added" LOCALIZED_STYLE_REF="AutomaticLayout.level,1" POSITION="right" ID="ID_1110855843" CREATED="1360711330232" MODIFIED="1369771277306">
<edge COLOR="#007c7c"/>
<font BOLD="true"/>
<node TEXT="In this section, styles have been applied manually. So if automatic layout is *off*, these should still become section headings." ID="ID_234136893" CREATED="1360937379803" MODIFIED="1369771485717"/>
<node TEXT="Subsection (Level 2)" LOCALIZED_STYLE_REF="AutomaticLayout.level,2" ID="ID_565464668" CREATED="1360937370766" MODIFIED="1369771423055">
<node TEXT="Subsubsection (Level 3)" LOCALIZED_STYLE_REF="AutomaticLayout.level,3" ID="ID_955364385" CREATED="1360937370766" MODIFIED="1369771456198">
<node TEXT="Level 4 without a sub-node" ID="ID_1778828827" CREATED="1369770993387" MODIFIED="1369771189078"/>
</node>
</node>
<node TEXT="Subsection (Level 2)" LOCALIZED_STYLE_REF="AutomaticLayout.level,2" ID="ID_1646424175" CREATED="1360937370766" MODIFIED="1369771441511">
<node TEXT="Subsubsection (Level 3)" ID="ID_1986521820" CREATED="1360937370766" MODIFIED="1369770986673">
<node TEXT="Level 4 with a node below" ID="ID_427078625" CREATED="1369770993387" MODIFIED="1369771087624">
<node TEXT="Level 5" ID="ID_1223018201" CREATED="1369770996803" MODIFIED="1369771000193"/>
</node>
</node>
</node>
<node TEXT="Level 2 without sub.node and not format set -&gt; body text." ID="ID_1674768633" CREATED="1360937370766" MODIFIED="1369771511635"/>
<node TEXT="Level 2 with a sub.node and not format set -&gt; still body text." ID="ID_1630863910" CREATED="1360937370766" MODIFIED="1369771561246">
<node TEXT="level 3" ID="ID_1516932695" CREATED="1369771562188" MODIFIED="1369771565178"/>
</node>
<node TEXT="Subsection (Level 2)" LOCALIZED_STYLE_REF="AutomaticLayout.level,2" ID="ID_634198060" CREATED="1360937370766" MODIFIED="1369771449558">
<node TEXT="Level 3 without sub.node and not format set -&gt; body text." ID="ID_521665391" CREATED="1360937370766" MODIFIED="1369771520042"/>
<node TEXT="Level 3 with a sub.node and not format set -&gt; still body text." ID="ID_163955672" CREATED="1360937370766" MODIFIED="1369771537003">
<node TEXT="level 4" ID="ID_1541741637" CREATED="1369771537829" MODIFIED="1369771539586"/>
</node>
</node>
</node>
<node TEXT="This is a node with a custom style" STYLE_REF="My Custom Style" POSITION="left" ID="ID_774793227" CREATED="1369774524333" MODIFIED="1369774941817"/>
<node TEXT="Below is an empty node" POSITION="left" ID="ID_1959957213" CREATED="1369937564084" MODIFIED="1369937639359">
<edge COLOR="#ff00ff"/>
<hook NAME="AlwaysUnfoldedNode"/>
<node TEXT="" ID="ID_1387090593" CREATED="1369937575163" MODIFIED="1369937575163">
<node TEXT="Above is an empty node" ID="ID_74465915" CREATED="1369937578323" MODIFIED="1369937585328"/>
</node>
</node>
<node TEXT="Below is an empty node - folded this time" FOLDED="true" POSITION="left" ID="ID_1373029824" CREATED="1369937564084" MODIFIED="1369937630015">
<edge COLOR="#ff00ff"/>
<node TEXT="" ID="ID_461583381" CREATED="1369937575163" MODIFIED="1369937575163">
<node TEXT="Above is an empty node" ID="ID_851874381" CREATED="1369937578323" MODIFIED="1369937585328"/>
</node>
</node>
<node TEXT="Now this is a&#xa;node with some&#xa;line-breaks in." POSITION="left" ID="ID_868297651" CREATED="1369937642234" MODIFIED="1369937662191">
<edge COLOR="#00ffff"/>
<node TEXT="Now this is a&#xa;node with some&#xa;line-breaks in." ID="ID_1391451392" CREATED="1369937642234" MODIFIED="1369937949689"/>
</node>
</node>
</map>

==> freeplane_1.7.10.orig.tar.gz: freeplane-1.7.10/freeplane_framework/test_data/StructuredMapTest.mm <==
<map version="freeplane 1.3.0">
<!--To view this file, download free mind mapping software Freeplane from https://www.freeplane.org -->
<node TEXT="Title of the Map" LOCALIZED_STYLE_REF="AutomaticLayout.level.root" FOLDED="false" ID="ID_1723255651" CREATED="1283093380553" MODIFIED="1369771838184"><hook NAME="MapStyle" zoom="0.75">

<map_styles>
<stylenode LOCALIZED_TEXT="styles.root_node">
<stylenode LOCALIZED_TEXT="styles.predefined" POSITION="right">
<stylenode LOCALIZED_TEXT="default" MAX_WIDTH="600" COLOR="#000000" STYLE="as_parent">
<font NAME="SansSerif" SIZE="10" BOLD="false" ITALIC="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.details" COLOR="#5a4de4"/>
<stylenode LOCALIZED_TEXT="defaultstyle.note" COLOR="#991414"/>
<stylenode LOCALIZED_TEXT="defaultstyle.floating">
<edge STYLE="hide_edge"/>
<cloud COLOR="#f0f0f0" SHAPE="ROUND_RECT"/>
</stylenode>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.user-defined" POSITION="right">
<stylenode LOCALIZED_TEXT="styles.topic" COLOR="#18898b" STYLE="fork">
<font NAME="Liberation Sans" SIZE="10" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subtopic" COLOR="#cc3300" STYLE="fork">
<font NAME="Liberation Sans" SIZE="10" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subsubtopic" COLOR="#669900">
<font NAME="Liberation Sans" SIZE="10" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.important">
<icon BUILTIN="yes"/>
</stylenode>
<stylenode TEXT="My Custom Style" COLOR="#1a9914" BACKGROUND_COLOR="#9fa9ef">
<font SIZE="22" BOLD="true"/>
<edge COLOR="#00ff00"/>
</stylenode>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.AutomaticLayout" POSITION="right">
<stylenode LOCALIZED_TEXT="AutomaticLayout.level.root" COLOR="#000000">
<font SIZE="18"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,1" COLOR="#0033ff">
<font SIZE="16"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,2" COLOR="#00b439">
<font SIZE="14"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,3" COLOR="#990000">
<font SIZE="12"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,4" COLOR="#111111">
<font SIZE="10"/>
</stylenode>
</stylenode>
</stylenode>
</map_styles>
</hook>
<hook NAME="AutomaticEdgeColor" COUNTER="5"/>
<node TEXT="Intro" LOCALIZED_STYLE_REF="AutomaticLayout.level,1" POSITION="right" ID="ID_708159329" CREATED="1360711330056" MODIFIED="1360937837727">
<edge COLOR="#ff0000"/>
<node TEXT="This should be &quot;Body text&quot;. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua." ID="ID_1000279327" CREATED="1360711330056" MODIFIED="1360937489828"/>
</node>
<node TEXT="A Section" LOCALIZED_STYLE_REF="AutomaticLayout.level,1" POSITION="right" ID="ID_1009103810" CREATED="1360711330082" MODIFIED="1360937837734">
<edge COLOR="#00ff00"/>
<node TEXT="This should be &quot;Body text&quot;. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua." ID="ID_185418190" CREATED="1360711330056" MODIFIED="1360937489828"/>
<node TEXT="Expected Behaviour" LOCALIZED_STYLE_REF="AutomaticLayout.level,2" ID="ID_1935555534" CREATED="1360711330141" MODIFIED="1360937832275">
<node TEXT="This should be &quot;Body text&quot;. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua." ID="ID_172406032" CREATED="1360711330056" MODIFIED="1360937489828"/>
<node TEXT="This text has Freeplane predefined style &quot;Details&quot; and should ideally become custom ODT-style &quot;details&quot;, too. detail, detail, detail, detail, detail, detail, detail, detail, detail, detail." LOCALIZED_STYLE_REF="defaultstyle.details" ID="ID_1286931197" CREATED="1360711330227" MODIFIED="1369934481347"/>
<node TEXT="This text has Freeplane predefined style &quot;Note&quot; and should ideally become custom ODT-style &quot;note&quot;, too. note, note, note, note, note, note, note, note." LOCALIZED_STYLE_REF="defaultstyle.note" ID="ID_409213814" CREATED="1360711330227" MODIFIED="1369767861422"/>
<node TEXT="The same should be true for other custom freeplane styles." ID="ID_939096506" CREATED="1360938425065" MODIFIED="1369767836466"/>
</node>
<node TEXT="Further improvement" LOCALIZED_STYLE_REF="AutomaticLayout.level,2" ID="ID_831477544" CREATED="1360711330213" MODIFIED="1360937855895">
<node TEXT="Now here are some ideas for further improvement:" ID="ID_1274680809" CREATED="1360711330056" MODIFIED="1360937943450"/>
<node TEXT="Nodes with &quot;node-numbering&quot; turned on should become numbered lists." ID="ID_1047522289" CREATED="1360938043210" MODIFIED="1369775173285">
<node TEXT="one" ID="ID_224533182" CREATED="1360937991333" MODIFIED="1360937994822" NUMBERED="true"/>
<node TEXT="two" ID="ID_1539142837" CREATED="1360937995693" MODIFIED="1360937999407" NUMBERED="true">
<node TEXT="one" LOCALIZED_STYLE_REF="default" ID="ID_460784059" CREATED="1360937991333" MODIFIED="1369934338039" NUMBERED="true"/>
<node TEXT="two" LOCALIZED_STYLE_REF="default" ID="ID_1390007073" CREATED="1360937995693" MODIFIED="1369934338056" NUMBERED="true"/>
<node TEXT="three" LOCALIZED_STYLE_REF="default" ID="ID_174188200" CREATED="1360938000382" MODIFIED="1369934338063" NUMBERED="true"/>
</node>
<node TEXT="three" ID="ID_1491209579" CREATED="1360938000382" MODIFIED="1360938002357" NUMBERED="true"/>
</node>
</node>
<node TEXT="Notes and rich-text nodes" LOCALIZED_STYLE_REF="AutomaticLayout.level,2" ID="ID_572664818" CREATED="1360938477054" MODIFIED="1360938526821">
<node ID="ID_850381882" CREATED="1360938533372" MODIFIED="1369945500063"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      Rich-texts nodes should just become formated as the rich-text is, using ODT-style &quot;body text&quot;.
    </p>
    <ul>
      <li>
        This is a first unnumbered list item in a rich-tex-node
      </li>
      <li>
        This is a second unnumbered list item in a rich-tex-no
      </li>
      <li>
        This is a forth unnumbered list item in a rich-tex-node
      </li>
    </ul>
  </body>
</html>

</richcontent>
</node>
<node TEXT="Rich-text Nodes and details should be formated the same." ID="ID_102700945" CREATED="1360938606807" MODIFIED="1369934446482"/>
</node>
</node>
<node TEXT="This Section has not styles applied" LOCALIZED_STYLE_REF="default" FOLDED="true" POSITION="right" ID="ID_52684190" CREATED="1360711330232" MODIFIED="1369771408084">
<edge COLOR="#007c7c"/>
<node TEXT="Thies section does not have any styles set. So this all sould becom text body, except if automatic stlyes are on." ID="ID_885260680" CREATED="1369771340439" MODIFIED="1369775408113" BACKGROUND_COLOR="#ffffff"/>
<node TEXT="Subsection (Level 2)" ID="ID_1705364067" CREATED="1360937370766" MODIFIED="1369770969648">
<node TEXT="Subsubsection (Level 3)" ID="ID_1625498929" CREATED="1360937370766" MODIFIED="1369770986673">
<node TEXT="Level 4 without a sub-node" ID="ID_1344868067" CREATED="1369770993387" MODIFIED="1369771189078"/>
</node>
</node>
<node TEXT="Subsection (Level 2)" ID="ID_626605938" CREATED="1360937370766" MODIFIED="1369770979798">
<node TEXT="Subsubsection (Level 3)" ID="ID_1557349195" CREATED="1360937370766" MODIFIED="1369770986673">
<node TEXT="Level 4 with a node below" ID="ID_539388565" CREATED="1369770993387" MODIFIED="1369771087624">
<node TEXT="Level 5" ID="ID_1912854001" CREATED="1369770996803" MODIFIED="1369771000193"/>
</node>
</node>
</node>
<node TEXT="Level 2 without sub.node" ID="ID_89526220" CREATED="1360937370766" MODIFIED="1369771069832"/>
<node TEXT="Subsection (Level 2)" ID="ID_1116673985" CREATED="1360937370766" MODIFIED="1369770979798">
<node TEXT="Level 3 without sub-node" ID="ID_1980164007" CREATED="1360937370766" MODIFIED="1369771137633"/>
</node>
</node>
<node TEXT="But this section has styles added" LOCALIZED_STYLE_REF="AutomaticLayout.level,1" POSITION="right" ID="ID_1110855843" CREATED="1360711330232" MODIFIED="1369771277306">
<edge COLOR="#007c7c"/>
<font BOLD="true"/>
<node TEXT="In this section, styles have been applied manually. So if automatic layout is *off*, these should still become section headings." ID="ID_234136893" CREATED="1360937379803" MODIFIED="1369771485717"/>
<node TEXT="Subsection (Level 2)" LOCALIZED_STYLE_REF="AutomaticLayout.level,2" ID="ID_565464668" CREATED="1360937370766" MODIFIED="1369771423055">
<node TEXT="Subsubsection (Level 3)" LOCALIZED_STYLE_REF="AutomaticLayout.level,3" ID="ID_955364385" CREATED="1360937370766" MODIFIED="1369771456198">
<node TEXT="Level 4 without a sub-node" ID="ID_1778828827" CREATED="1369770993387" MODIFIED="1369771189078"/>
</node>
</node>
<node TEXT="Subsection (Level 2)" LOCALIZED_STYLE_REF="AutomaticLayout.level,2" ID="ID_1646424175" CREATED="1360937370766" MODIFIED="1369771441511">
<node TEXT="Subsubsection (Level 3)" ID="ID_1986521820" CREATED="1360937370766" MODIFIED="1369770986673">
<node TEXT="Level 4 with a node below" ID="ID_427078625" CREATED="1369770993387" MODIFIED="1369771087624">
<node TEXT="Level 5" ID="ID_1223018201" CREATED="1369770996803" MODIFIED="1369771000193"/>
</node>
</node>
</node>
<node TEXT="Level 2 without sub.node and not format set -&gt; body text." ID="ID_1674768633" CREATED="1360937370766" MODIFIED="1369771511635"/>
<node TEXT="Level 2 with a sub.node and not format set -&gt; still body text." ID="ID_1630863910" CREATED="1360937370766" MODIFIED="1369771561246">
<node TEXT="level 3" ID="ID_1516932695" CREATED="1369771562188" MODIFIED="1369771565178"/>
</node>
<node TEXT="Subsection (Level 2)" LOCALIZED_STYLE_REF="AutomaticLayout.level,2" ID="ID_634198060" CREATED="1360937370766" MODIFIED="1369771449558">
<node TEXT="Level 3 without sub.node and not format set -&gt; body text." ID="ID_521665391" CREATED="1360937370766" MODIFIED="1369771520042"/>
<node TEXT="Level 3 with a sub.node and not format set -&gt; still body text." ID="ID_163955672" CREATED="1360937370766" MODIFIED="1369771537003">
<node TEXT="level 4" ID="ID_1541741637" CREATED="1369771537829" MODIFIED="1369771539586"/>
</node>
</node>
</node>
<node TEXT="This is a node with a custom style" STYLE_REF="My Custom Style" POSITION="left" ID="ID_774793227" CREATED="1369774524333" MODIFIED="1369774941817"/>
<node TEXT="Below is an empty node" POSITION="left" ID="ID_1959957213" CREATED="1369937564084" MODIFIED="1369937639359">
<edge COLOR="#ff00ff"/>
<hook NAME="AlwaysUnfoldedNode"/>
<node TEXT="" ID="ID_1387090593" CREATED="1369937575163" MODIFIED="1369937575163">
<node TEXT="Above is an empty node" ID="ID_74465915" CREATED="1369937578323" MODIFIED="1369937585328"/>
</node>
</node>
<node TEXT="Below is an empty node - folded this time" FOLDED="true" POSITION="left" ID="ID_1373029824" CREATED="1369937564084" MODIFIED="1369937630015">
<edge COLOR="#ff00ff"/>
<node TEXT="" ID="ID_461583381" CREATED="1369937575163" MODIFIED="1369937575163">
<node TEXT="Above is an empty node" ID="ID_851874381" CREATED="1369937578323" MODIFIED="1369937585328"/>
</node>
</node>
<node TEXT="Now this is a&#xa;node with some&#xa;line-breaks in." POSITION="left" ID="ID_868297651" CREATED="1369937642234" MODIFIED="1369937662191">
<edge COLOR="#00ffff"/>
<node TEXT="Now this is a&#xa;node with some&#xa;line-breaks in." ID="ID_1391451392" CREATED="1369937642234" MODIFIED="1369937949689"/>
</node>
</node>
</map>
